/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the Concurrent GA5000 keyboard.
 * By black@westford.ccur.com.
 */

static const KeyCode ga5k_codes [] = {

  /* Row 0 */
  145,
  162, 151, 163, 152,
  164, 153, 154, 165,
  155, 166, 156, 168,
  146, 170, 133,

  /* Row 2 */
  245, 177, 178, 179, 180, 181, 182, 183, 184, 185, 176, 173, 189, 136,
  157, 169, 158,
  171, 186, 191, 230,

  /* Row 3 */
  137, 209, 215, 197, 210, 212, 217, 213, 201, 207, 208, 227, 221, 188,
  255, 161, 159,
  232, 234, 231, 242,
  
  /* Row 4 */
  129, 193, 211, 196, 198, 199, 200, 202, 203, 204, 187, 167, 141,
  240, 243, 239,

  /* Row 5 */
  128, 218, 216, 185, 214, 194, 206, 205, 172, 174, 175, 139,
  241,
  244, 149, 148, 134,

  /* Row 6 */
  130,
  140, 160, 220,
  138,
  147, 144, 150,
  143, 142
};
